pub struct MemorySearchSkill { /* private fields */ }Expand description
Skill that searches the vector memory for similar text.
Implementations
Sourceimpl MemorySearchSkill
impl MemorySearchSkill
Sourcepub fn new(
store: Arc<dyn VectorStore>,
embedder: Arc<dyn EmbeddingProvider>,
) -> Self
pub fn new( store: Arc<dyn VectorStore>, embedder: Arc<dyn EmbeddingProvider>, ) -> Self
Create a new memory-search skill using the given vector store and embedding provider.