pub struct ShellSkill { /* private fields */ }Expand description
Shell execution skill with production-grade command validation.
Commands are parsed into segments (split on shell metacharacters) and each
segment’s base command is validated against the configured CommandPolicy.
Additionally, a set of unconditionally dangerous patterns is always blocked
regardless of policy configuration.
Implementations
Sourceimpl ShellSkill
impl ShellSkill
Sourcepub fn with_policy(policy: CommandPolicy) -> Self
pub fn with_policy(policy: CommandPolicy) -> Self
Create a new ShellSkill with a custom CommandPolicy.
Sourcepub fn with_max_stdout_bytes(self, max: usize) -> Self
pub fn with_max_stdout_bytes(self, max: usize) -> Self
Set the maximum number of bytes to capture from stdout.
Sourcepub fn with_max_stderr_bytes(self, max: usize) -> Self
pub fn with_max_stderr_bytes(self, max: usize) -> Self
Set the maximum number of bytes to capture from stderr.